@@ -11,8 +11,7 @@ from toxopy import trials
 
 
 def jsonify_dlc_avgs(csv_file):
-
-    # csv_file is a .csv file with all the data from all the experiment trials
+    """csv_file is one file with all the experiment data"""
 
     df = pd.read_csv(csv_file)
 
@@ -25,18 +24,20 @@ def jsonify_dlc_avgs(csv_file):
 
     d = {}
 
+    vars1 = ['distance', 'cat_distance', 'vel', 'acceleration']
+    vars2 = ['distance_loess05', 'cat_distance_loess05',
+             'velocity_loess05', 'acceleration_loess05']
+
     for cat in cats:
 
         df2 = df.loc[(df['cat'] == cat)]
         d[cat] = {}
 
         for t in tls:
-            df3 = df2.loc[(df['trial'] == t)]
             d[cat][t] = {}
-            d[cat][t]['distance'] = mean(df3['distance_loess05'])
-            d[cat][t]['cat_distance'] = mean(df3['cat_distance_loess05'])
-            d[cat][t]['vel'] = mean(df3['velocity_loess05'])
-            d[cat][t]['acceleration'] = mean(df3['acceleration_loess05'])
+            df3 = df2.loc[(df['trial'] == t)]
+            for i, j in zip(vars1, vars2):
+                d[cat][t][i] = mean(df3[j])
             d[cat][t]['moving'] = percentage(sum(df3['moving']), len(df2))
 
     with open('dlc_avgs.json', 'w') as outfile:
